@@ -11,4 +11,4 @@ def post(data={}):
 	"""
 	params={}
 	path='/batches/current/close'
-	return run_call('post',path,data,params)
+	return run_call('post','json',path,data,params)
