@@ -16,4 +16,4 @@ def post(data={}):
 	params={}
 	path='/invoices/bulk/send'
 	data_list = data['Keys']
-	return run_call('post',path,data,params)
+	return run_call('post','json',path,data_list,params)
