@@ -11,4 +11,4 @@ def get(data={}):
 	"""
 	params={}
 	path='/invoices/columns'
-	return run_call('get',path,data,params)
+	return run_call('get','json',path,data,params)
