@@ -18,4 +18,4 @@ def post(data={}):
 		raise Exception('invoice_key required for invoices.send.post()')
 
 	path='/invoices/' + data['invoice_key'] + '/send'
-	return run_call('post',path,data,params)
+	return run_call('post','json',path,data,params)
