@@ -15,6 +15,8 @@ def get(data={}):
 		String
 	"""
 	params={}
+	if not 'receipt_key' in data:
+			data['receipt_key']='vterm'
 	if not 'trankey' in data:
 		raise Exception('trankey required for transactions.receipts.get()')
 
@@ -22,4 +24,4 @@ def get(data={}):
 		raise Exception('receipt_key required for transactions.receipts.get()')
 
 	path='/transactions/' + data['trankey'] + '/receipts'+ '/' + data['receipt_key']
-	return run_call('get',path,data,params)
+	return run_call('get','base64',path,data,params)
